==> grommet-2.7.1.tgz: package/components/Select/stories/CustomValue.js <==
"use strict";

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@storybook/react");

var _grommetIcons = require("grommet-icons");

var _grommet = require("grommet");

var _themes = require("grommet/themes");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var CustomSelectValue =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(CustomSelectValue, _Component);

  function CustomSelectValue() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "state", {
      options: ['one', 'two'],
      value: undefined
    });

    return _this;
  }

  var _proto = CustomSelectValue.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$state = this.state,
        options = _this$state.options,
        value = _this$state.value;
    return _react.default.createElement(_grommet.Grommet, {
      full: true,
      theme: _themes.grommet
    }, _react.default.createElement(_grommet.Box, {
      fill: true,
      align: "center",
      justify: "start",
      pad: "large"
    }, _react.default.createElement(_grommet.Select, _extends({
      id: "select",
      name: "select",
      placeholder: "Select",
      value: value,
      options: options,
      onChange: function onChange(_ref) {
        var option = _ref.option;
        return _this2.setState({
          value: option
        });
      },
      plain: true,
      valueLabel: _react.default.createElement(_grommet.Box, {
        background: "brand",
        width: "small",
        round: "small",
        overflow: "hidden",
        align: "center"
      }, value || 'Select...'),
      icon: false
    }, this.props))));
  };

  return CustomSelectValue;
}(_react.Component);

(0, _react2.storiesOf)('Select', module).add('Custom Value', function () {
  return _react.default.createElement(CustomSelectValue, null);
}).add('Custom Icon', function () {
  return _react.default.createElement(CustomSelectValue, {
    icon: _react.default.createElement(_grommet.Box, null, _react.default.createElement(_grommetIcons.CaretDown, {
      color: "black"
    }))
  });
});

==> grommet-2.7.2.tgz: package/components/Select/stories/CustomValue.js <==
"use strict";

var _react = _interopRequireWildcard(require("react"));

var _react2 = require("@storybook/react");

var _grommetIcons = require("grommet-icons");

var _grommet = require("grommet");

var _themes = require("grommet/themes");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var CustomSelectValue =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(CustomSelectValue, _Component);

  function CustomSelectValue() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "state", {
      options: ['one', 'two'],
      value: undefined
    });

    return _this;
  }

  var _proto = CustomSelectValue.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$state = this.state,
        options = _this$state.options,
        value = _this$state.value;
    return _react["default"].createElement(_grommet.Grommet, {
      full: true,
      theme: _themes.grommet
    }, _react["default"].createElement(_grommet.Box, {
      fill: true,
      align: "center",
      justify: "start",
      pad: "large"
    }, _react["default"].createElement(_grommet.Select, _extends({
      id: "select",
      name: "select",
      placeholder: "Select",
      value: value,
      options: options,
      onChange: function onChange(_ref) {
        var option = _ref.option;
        return _this2.setState({
          value: option
        });
      },
      plain: true,
      valueLabel: _react["default"].createElement(_grommet.Box, {
        background: "brand",
        width: "small",
        round: "small",
        overflow: "hidden",
        align: "center"
      }, value || 'Select...'),
      icon: false
    }, this.props))));
  };

  return CustomSelectValue;
}(_react.Component);

(0, _react2.storiesOf)('Select', module).add('Custom Value', function () {
  return _react["default"].createElement(CustomSelectValue, null);
}).add('Custom Icon', function () {
  return _react["default"].createElement(CustomSelectValue, {
    icon: _react["default"].createElement(_grommet.Box, null, _react["default"].createElement(_grommetIcons.CaretDown, {
      color: "black"
    }))
  });
});
